/*
 * Copyright (C) 2022 luca0N!
 *
 * This file is part of Static Website Generator (swg).
 *
 * Static Website Generator (swg) is free software: you can redistribute it
 * and/or modify it under the terms of the version 3 of the GNU Lesser General
 * Public License as published by the Free Software Foundation.
 *
 * Static Website Generator (swg) is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Static Website Generator (swg). If not, see
 * <https://www.gnu.org/licenses/>.
 *
 * Contact luca0N! by e-mail: <luca0n [at] luca0n [dot] com>. 
 */

#include <iostream>
#include <cstring>
#include <string>
#include <list>
#include <regex>

#include <filesystem>

#include "SwgContext.hxx"
#include "ConfigUtils.hxx"
// #include "Blog.h"
#include "Common.hxx"
#include "WebsiteBuilder.hxx"

void printUsage(const char *programName) {
	std::cerr << programName << ": usage: " << programName << " [path]"
		<< std::endl;
}

void printIntro() {
	printf("%s v%s (%d)\nCopyright (C) %s %s\n\n",
			PROGRAM_NAME, PROGRAM_VERSION_NAME, PROGRAM_VERSION,
			PROGRAM_COPYRIGHT_YEARS, PROGRAM_COPYRIGHT);
}

int main(int argc, char *argv[]) {
	printIntro();

	std::string path;

	// Parse cmdline options
	switch (argc) {
		case 1:
			path = ".";
			std::cout << "Assuming working directory is \".\""
				<< std::endl;
			break;
		case 2:
			path = argv[1];
			std::cout << "Using specified directory: "
				<< path << std::endl;
			break;
		default:
			printUsage(argv[0]);
			exit(RETURN_FAILED_INVALID_SYNTAX);
			break;
	}

	SwgContext ctx;
	parse_config(&ctx, path);

	build_website(ctx, path);

	// Website blog

	// Append blog to website
	//ctx.appendBlog(blog1);

	// Generate website
	//ctx.generateWebsite();

	return 0;
}
